# Encoding: UTF-8
#
# Cookbook Name:: x2go-server
# Library:: provider_x2go_server_app_rhel
#
# Copyright 2014-2015 Jonathan Hartman
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require 'chef/dsl/include_recipe'
require 'chef/provider/lwrp_base'
require_relative 'provider_x2go_server_app'

class Chef
  class Provider
    class X2goServerApp < LWRPBase
      # A Chef provider for the X2go server packages for RHEL and RHEL-alikes.
      #
      # @author Jonathan Hartman <jonathan.hartman@socrata.com>
      class Rhel < X2goServerApp
        include Chef::DSL::IncludeRecipe

        if defined?(provides)
          provides :x2go_server_app, platform: %w(redhat centos scientific)
        end

        private

        #
        # Set up EPEL and install the X2go server packages. EPEL must always be
        # set up, even if a custom package source is provided, due to x2go's
        # dependencies on, e.g., sshfs.
        #
        # (see Chef::Provider::X2goServerApp#install!)
        #
        def install!
          include_recipe 'yum-epel'
          super
        end
      end
    end
  end
end
