# Encoding: UTF-8
#
# Cookbook Name:: x2go-server
# Library:: provider_x2go_server_service_rhel
#
# Copyright 2015 Socrata, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require 'chef/provider/lwrp_base'
require_relative 'resource_x2go_server_service'
require_relative 'provider_x2go_server_service'

class Chef
  class Provider
    class X2goServerService < LWRPBase
      # A Chef provider for the X2go server service on RHEL and RHEL-alike
      # platforms where the service name is 'x2gocleansessions' instead of
      # 'x2goserver'.
      #
      # @author Jonathan Hartman <jonathan.hartman@socrata.com>
      class Rhel < X2goServerService
        if defined?(provides)
          provides :x2go_server_service, platform_family: 'rhel'
        end

        private

        #
        # Override the service resource to use the RHEL service name. The
        # service script on RHEL also works properly, so hardcoded status
        # commands are not needed.
        #
        # (see Chef::Provider::X2goServerService#x2go_service)
        #
        def x2go_service(do_action)
          service 'x2gocleansessions' do
            action do_action
          end
        end
      end
    end
  end
end
